/**
 * The only true department-selector.
 * @date 2018.12.8
 * @version 0.0.1
 * @author Campbell.Jiao
 */

import * as React from 'react';
import * as module from './module';
import { others } from 'fit-transmit-transparently';
import { Tree } from 'antd';
import "./style.less";
import IrsFetchHttp from '../../../http/irs-fetch/http';
const TreeNode = Tree.TreeNode;
const dataList:any = [];
let parentKey = '';
let parentText = '';
const getDepartment = () => {
    const settingData = new IrsFetchHttp().get(
        "/web/common/department/getDepartmentTree.do",
        null
    );
    return {
        data:settingData
    }
}
class IrsDepartmentSelector extends React.Component<module.IPropsInterface, any> {
    static defaultProps = {
        selectWidth:'300px'
    }
    constructor(props:module.IPropsInterface) {
        super(props)
        this.state = {
            gData:[],
            disabledIds: [],
            searchValue:'',
            checkedKeys:[],
        }
    }
    componentWillMount() {
        getDepartment().data.then((res:any) => {
            if(res && res.departmentList) {
                this.setState({gData: res.departmentList},() => {
                    this.setState({expandedKeys: this.state.gData.length !== 0 ? [this.state.gData[0].departmentId.toString()] : []});
                });
                this.changeKeyName(res.departmentList);
                this.generateList(res.departmentList);
            }
        })
    } 
    componentWillReceiveProps(nextProps: any) {//props更新时触发的函数
        const checkedKeys = nextProps.value;
        this.setState({
            checkedKeys
        })
    }
    getParentKey = (title:any, tree:any) => {
        tree.forEach((i:any, index:any) => {
            const node = i;
            if (node.children) {
                if (node.children.some((item:any) => item.text === title)) {
                    parentKey = node.key;
                } else if (this.getParentKey(title, node.children)) {
                    parentKey = this.getParentKey(title, node.children);
                }
            }
        })
        return parentKey.toString();
    };
    changeKeyName = (tree:any) => {
        tree.forEach((i:any, index:any) => {
            const node = i;
            node.key = node.departmentId;
            node.disabled = false;
            if (node.children) {
                this.changeKeyName(node.children);
            }
        })
    }   
    getName = (key:any, tree:any) => {
        tree.forEach((i:any, index:any) => {
            const node = i;
            if (+node.departmentId === +key) {
                parentText = node.text;
            } else {
                if (node.children) {
                    this.getName(key, node.children);
                }
            }
        })
        return parentText;
    }
    generateList = (data:any) => {
        data.forEach((i:any, index:any) => {
            const node = i;
            const akey = node.key;
            dataList.push({key:akey, title: node.text});
            if (node.children) {
                this.generateList(node.children);
            }
        })
        this.setState({dataList});
    };

    onExpand = (expandedKeys:any) => {
        this.setState({
            expandedKeys,
            autoExpandParent: false,
        });
    };

    onChange = (e:any) => {
        const value = e.target.value;
        const expandedKeys = this.state.dataList.map((item:any) => {
            if (item.title.indexOf(value) > -1) {
                return this.getParentKey(item.title, this.state.gData);
            }
            return null;
        }).filter((item:any, i:any, self:any) => item && self.indexOf(item) === i);
        this.setState({
            expandedKeys,
            searchValue: value,
            autoExpandParent: false,
        });
    };

    onCheck = (checkedKeys:any) => {
        const List = this.state.dataList;
        const selectId = checkedKeys;
        // let departmentString = '';
        const departmentListSelected:any = []
        selectId.map((value:any) => {
            List.map((context:any) => {
                if((value - 0) === context.key) {
                    // departmentString += context.title + ';'
                    departmentListSelected.push(context);
                }
            })
        })
        this.setState({
            checkedKeys,
        })
        this.props.onChange(departmentListSelected,checkedKeys);
    }
    loop = (data:any) => data.map((item:any) => {
        const {searchValue} = this.state;
        const index = item.text.indexOf(searchValue);
        const beforeStr = item.text.substr(0, index);
        const afterStr = item.text.substr(index + searchValue.length);
        const title = index > -1 ? (
            <span>
                {beforeStr}
                <span style={{color: '#f50'}}>{searchValue}</span>
                {afterStr}
                </span>
        ) : <span>{item.text}</span>;
        if (item.children) {
            return (
                <TreeNode key={item.key} title={title} dataRef={item} disabled={item.disabled}>
                    {this.loop(item.children)}
                </TreeNode>
            );
        }
        return <TreeNode dataRef={item} key={item.key} title={title} disabled={item.disabled} />;
    });

    public render() {
        others(IrsDepartmentSelector.defaultProps, this.props);
        return(
            <div style={{width:this.props.selectWidth}}>
                <span className="ant-input-search ant-input-affix-wrapper" style={{ marginBottom: '8px' }}>
                    <input placeholder="输入部门名称" className="ant-input" type="text" onChange={this.onChange} />
                    <span className="ant-input-suffix">
                        <i className="anticon anticon-search ant-input-search-icon" />
                    </span>
                </span>
                <Tree checkable={true}
                    onCheck={this.onCheck}
                    onExpand={this.onExpand}
                    checkedKeys={{'checked':this.state.checkedKeys,'halfChecked':this.state.checkedKeys}}
                    expandedKeys={this.state.expandedKeys}
                    defaultExpandAll={true}
                >
                    {this.loop(this.state.gData)}
                </Tree>
            </div>
        )
    }
}
export default IrsDepartmentSelector