### 1.变更记录

变更时间 | 变更版本 | 变更人 | 变更内容
:-: | :-: | :-: | :-: |
2018.12.8 | V0.0.1 | Danae | 新增穿梭框组件

<br><br/>
### 2.安装方式
<code>
npm install irs-transfer
</code>

<br><br/><br><br/>
### 3. 调用方式
#### 基本用法
选择一个或以上的选项后，点击对应的方向键，可以把选中的选项移动到另一栏。 其中，左边一栏为 source，右边一栏为 target
```jsx
class IrsTransferDemo extends React.Component {
  constructor() {
    super()
    this.state = {
      mockData: [],
      targetKeys: [],
      selectedKeys: [],
      disabled: false,
    }
    this.handleChange = this.handleChange.bind(this);
    this.handleScroll = this.handleScroll.bind(this);
    this.handleSelectChange = this.handleSelectChange.bind(this);
    this.handleDisable = this.handleDisable.bind(this)
  }
  componentWillMount() {
    const targetKeys = [];
    const mockData = [];
    for (let i = 0; i < 20; i++) {
      const data = {
        key: i.toString(),
        title: `content${i + 1}`,
        description: `description of content${i + 1}`,
        chosen: Math.random() * 2 > 1,
      };
      if (data.chosen) {
        targetKeys.push(data.key);
      }
      mockData.push(data);
    }
    const oriTargetKeys = mockData.filter(item => + item.key % 3 > 1).map(item => item.key);
    this.setState({ mockData, targetKeys, oriTargetKeys });
  }
  handleChange(targetKeys, direction, moveKeys) {
    this.setState({ targetKeys });
    console.log(targetKeys, direction, moveKeys);
  }
  handleSelectChange(sourceSelectedKeys, targetSelectedKeys) {
    this.setState({ selectedKeys: [...sourceSelectedKeys, ...targetSelectedKeys] });
  }
  handleScroll(direction, e) {
    console.log('direction:', direction);
    console.log('target:', e.target);
  }
  handleDisable(disabled) {
    this.setState({ disabled })
  }
  render() {
    const { mockData, targetKeys, selectedKeys, disabled } = this.state;
    return (
      <div className="App">
        <IrsTransfer
          dataSource={mockData}
          render={item => item.title}
          titles={['源文件', '目标文件']}
          targetKeys={targetKeys}
          selectedKeys={selectedKeys}
          onChange={this.handleChange}
          onSelectChange={this.handleSelectChange}
          onScroll={this.handleScroll}
          disabled={disabled}
        />
        <IrsSwitch 
          checkedChildren="on" 
          unCheckedChildren="off"
          checked={disabled} 
          onChange={this.handleDisable} 
        />
      </div>
    )
  }
};
<IrsTransferDemo />
```

#### 带搜索框
带搜索框的穿梭框，可以自定义搜索函数
```jsx
class IrsTransferDemo extends React.Component {
  constructor() {
    super()
    this.state = {
      mockData: [],
      targetKeys: []
    }
    this.handleChange = this.handleChange.bind(this);
    this.filterOption = this.filterOption.bind(this);
    this.handleSearchChange = this.handleSearchChange.bind(this)
  }
  componentWillMount() {
    const targetKeys = [];
    const mockData = [];
    for (let i = 0; i < 20; i++) {
      const data = {
        key: i.toString(),
        title: `content${i + 1}`,
        description: `description of content${i + 1}`,
        chosen: Math.random() * 2 > 1,
      };
      if (data.chosen) {
        targetKeys.push(data.key);
      }
      mockData.push(data);
    }
    this.setState({ mockData, targetKeys });
  }
  handleChange(targetKeys, direction, moveKeys) {
    this.setState({ targetKeys });
    console.log(targetKeys, direction, moveKeys);
  }
  handleSearchChange(direction, e) {
    console.log(direction, e.target.value)
  }
  filterOption (inputValue, option) {
    return option.description.indexOf(inputValue) > -1
  }
  render() {
    const { mockData, targetKeys } = this.state;
    return (
      <div className="App">
        <IrsTransfer
          dataSource={mockData}
          showSearch
          filterOption={this.filterOption}
          targetKeys={targetKeys}
          onChange={this.handleChange}
          onSearchChange={this.handleSearchChange}
          render={item => item.title}
        />
      </div>
    )
  }
};
<IrsTransferDemo />
```

#### 高级用法
可配置操作文案，可定制宽高，可对底部进行自定义渲染
```jsx
class IrsTransferDemo extends React.Component {
  constructor() {
    super()
    this.state = {
      mockData: [],
      targetKeys: [],
      locale: {
        itemUnit: '项',
        itemsUnit: '项',
        notFoundContent: '列表为空',
        searchPlaceholder: '请输入搜索内容'
      }
    }
    this.renderFooter = this.renderFooter.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.getMock = this.getMock.bind(this);
  }
  componentDidMount() {
    this.getMock();
  }
  getMock () {
    const targetKeys = [];
    const mockData = [];
    for (let i = 0; i < 20; i++) {
      const data = {
        key: i.toString(),
        title: `content${i + 1}`,
        description: `description of content${i + 1}`,
        chosen: Math.random() * 2 > 1,
      };
      if (data.chosen) {
        targetKeys.push(data.key);
      }
      mockData.push(data);
    }
    this.setState({ mockData, targetKeys });
  }
  renderFooter(){
    return (<IrsButton
      size="small"
      style={{ float: 'right', margin: 0 }}
      onClick={this.getMock}
    >还原</IrsButton>)
  }
  handleChange(targetKeys, direction, moveKeys) {
    this.setState({ targetKeys });
    console.log('targetKeys:', targetKeys);
    console.log('direction:', direction);
    console.log('moveKeys', moveKeys);
  }
  render() {
    const { mockData, targetKeys, locale } = this.state;
    return (
      <div className="App">
        <IrsTransfer
          dataSource={mockData}
          render={item => `${item.title}-${item.description}`}
          listStyle={{
            width: 250,
            height: 300,
          }}
          operations={['向右', '向左']}
          showSearch
          targetKeys={targetKeys}
          footer={this.renderFooter}
          onChange={this.handleChange}
          locale={locale}
        />
      </div>
    )
  }
};
<IrsTransferDemo />
```

#### 自定义渲染行数据
自定义渲染每一个 Transfer Item，可用于渲染复杂数据。
```jsx
class IrsTransferDemo extends React.Component {
  constructor() {
    super()
    this.state = {
      mockData: [],
      targetKeys: [],
    }
    this.handleChange = this.handleChange.bind(this);
    this.getMock = this.getMock.bind(this);
    this.renderItem = this.renderItem.bind(this);
  }
  componentDidMount() {
    this.getMock();
  }
  getMock () {
    const targetKeys = [];
    const mockData = [];
    for (let i = 0; i < 20; i++) {
      const data = {
        key: i.toString(),
        title: `content${i + 1}`,
        description: `description of content${i + 1}`,
        chosen: Math.random() * 2 > 1,
      };
      if (data.chosen) {
        targetKeys.push(data.key);
      }
      mockData.push(data);
    }
    this.setState({ mockData, targetKeys });
  }
  handleChange(targetKeys, direction, moveKeys) {
    this.setState({ targetKeys });
    console.log('targetKeys:', targetKeys);
    console.log('direction:', direction);
    console.log('moveKeys', moveKeys);
  }
  renderItem (item) {
    const customLabel = (
      <span className="custom-item">
        {item.title} - {item.description}
      </span>
    );
    return {
      label: customLabel,
      value: item.title,
    };
  }
  render() {
    const { mockData, targetKeys } = this.state;
    return (
      <div className="App">
        <IrsTransfer
          dataSource={mockData}
          render={this.renderItem}
          listStyle={{
            width: 250,
            height: 300,
          }}
          targetKeys={targetKeys}
          onChange={this.handleChange}
        />
      </div>
    )
  }
};
<IrsTransferDemo />
```
