/**
 * The only true datePicker.
 * @date 2018.11.27
 * @version 0.0.1
 * @author Gail.Chen
 */
import * as React from 'react';
// import * as classNames from 'classnames';
import * as module from './module';
import * as moment from "moment";
// import 'moment/locale/zh-cn';
// moment.locale('zh-cn');
import locale from 'antd/lib/date-picker/locale/zh_CN';
// import './style.less';
import { DatePicker } from 'antd';
const { MonthPicker, RangePicker, WeekPicker } = DatePicker;
// import { IrsDatePicker } from '../../../..';
import { others } from 'fit-transmit-transparently';
export declare type RangePickerValue = undefined[] | [moment.Moment] | [undefined, moment.Moment] | [moment.Moment, moment.Moment];
class IrsDatePicker extends React.Component<module.IPropsInterface, any> {
    static defaultProps = {
        type: "datepicker",
        showToday: true,
        showTime: false,
        disabled: false
    }
    constructor(props: module.IPropsInterface) {
        super(props);
        this.state = {
            isDefinedValue: false,
            isDefinedRange: false,
            value: undefined
        };
        this.handleChange = this.handleChange.bind(this);
    }
    componentWillMount() {
        this.setState({isDefinedValue: this.props.isDefinedValue ? this.props.isDefinedValue : false,
            isDefinedRange: this.props.isDefinedRange ? this.props.isDefinedRange : false})
    }
    handleChange = (date: moment.Moment, dateString: string) => {
        if (!this.state.isDefinedValue) {
            this.setState({value: date});
        }
        if (this.props.onChange) {
            this.props.onChange(date, dateString);
        }
    }
    handleRangeChange = (dates: RangePickerValue, dateStrings: [string, string]) => {
        if (!this.state.isDefinedValue) {
            this.setState({value: dates});
        }
        if (this.props.onRangeChange) {
            this.props.onRangeChange(dates, dateStrings);
        }
    }
    handlePanelChange = (value?: RangePickerValue, mode?: string | string[]) => {
        if (this.props.onPanelChange) {
            this.props.onPanelChange(value, mode);
        }
    }
    handleDisabledTime = (current: moment.Moment) => {
        return this.props.disabledTime ? this.props.disabledTime(current) : {};
    }
    handleDisabledDate = (current: moment.Moment) => {
        return this.props.disabledDate ? this.props.disabledDate(current) : false;
    }
    handleDateOnOk = (selectedTime: any) => {
        if (this.props.onOk) {
            this.props.onOk(selectedTime);
        }
    }
    handleRangeOnOk = (selectedTime: any) => {
        if (this.props.onOk) {
            this.props.onOk(selectedTime);
        }
    }
    handleOpenChange = (status: boolean) => {
        if (!this.state.isDefinedRange) {
            this.setState({open: status});
        } else {
            if (this.props.onOpenChange) {
                this.props.onOpenChange(status);
            }
        }
    }
    // 对数据判空
    isEmpty = (obj: any) => {
        if (typeof obj === "undefined" || obj === null || obj === "") {
            return true;
        }
        return false;
    }
    render() {
        others(IrsDatePicker.defaultProps, this.props);
        const { isEmpty, 
            handleChange, 
            handleRangeChange,
            handlePanelChange, 
            handleDisabledTime, 
            handleDisabledDate,
            handleDateOnOk,
            handleRangeOnOk,
            handleOpenChange } = this;
        const {
            isDefinedValue,
            isDefinedRange
        } = this.state;
        let content = null;
        const parmas = {
            id: this.props.id,
            allowClear: isEmpty(this.props.allowClear) ? true : this.props.allowClear,
            className: this.props.className,
            style: this.props.style,
            disabled: this.props.disabled,
            format: this.props.format,
            locale: isEmpty(this.props.locale) ? locale : this.props.locale,
            open: isDefinedRange ? this.props.open : this.state.open
        }
        switch (this.props.type) {
            case "datepicker":
                content = 
                    <DatePicker 
                        {...this.props}
                        {...parmas}
                        value={isDefinedValue ? 
                            isEmpty(this.props.value) ? undefined : this.props.value : this.state.value}
                        defaultValue={this.props.defaultValue}
                        onChange={handleChange}
                        disabledTime={handleDisabledTime}
                        disabledDate={handleDisabledDate}
                        onOk={handleDateOnOk}
                        placeholder={isEmpty(this.props.placeholder) ? '请选择日期' : this.props.placeholder}
                        onOpenChange={handleOpenChange}
                        />;
                break;
            case "monthpicker":
                content =
                    <MonthPicker 
                        {...this.props}
                        {...parmas}
                        value={isDefinedValue ? 
                            isEmpty(this.props.value) ? undefined : this.props.value : this.state.value}
                        defaultValue={this.props.defaultValue}
                        onChange={handleChange}
                        disabledDate={handleDisabledDate}
                        placeholder={isEmpty(this.props.placeholder) ? '请选择月份' : this.props.placeholder}
                        onOpenChange={handleOpenChange}
                        />;
                break;
            case "rangepicker":
                content = 
                    <RangePicker 
                        {...this.props}
                        {...parmas}
                        value={isDefinedValue ? 
                            isEmpty(this.props.value) ? undefined : this.props.value : this.state.value}
                        onChange={handleRangeChange}
                        disabledDate={handleDisabledDate}
                        onPanelChange={handlePanelChange}
                        disabledTime={handleDisabledTime}
                        placeholder={isEmpty(this.props.rangePlaceholder) ? ['开始日期' ,'结束日期'] : this.props.rangePlaceholder}
                        onOk={handleRangeOnOk}
                        locale={isEmpty(this.props.locale) ? locale : this.props.locale}
                        defaultValue={this.props.rangeDefaultValue}
                        onOpenChange={handleOpenChange}
                        />;
                break;
            case "weekpicker":
                content = 
                    <WeekPicker 
                        {...this.props}
                        {...parmas}
                        value={isDefinedValue ? 
                            isEmpty(this.props.value) ? undefined : this.props.value : this.state.value}
                        onChange={handleChange}
                        disabledDate={handleDisabledDate}
                        disabled={this.props.disabled}
                        placeholder={isEmpty(this.props.placeholder) ? '请选择时间' : this.props.placeholder}
                        defaultValue={this.props.defaultValue}
                        onOpenChange={handleOpenChange}
                        />;
                break;
            default:
                break;
        }
        return (
            <div style={this.props.labelType === 'vertical' ? {
                'display' : 'inline-flex',
                'flexDirection': 'column',
                'justifyContent': 'space-between'
            } : {
                'display' : 'inline-flex',
                'alignItems': 'center'
            }}>
                {this.props.label ? <label>{this.props.label}：</label> : null}
                {content}
            </div>
        )
    }
} 

export default IrsDatePicker;
