import * as React from 'react';

export interface IPropsInterface {
    
    /** 组件id */
    id?: string,

    /** 组件class */
    className?: any,
    
    /** 声明 input 类型，同原生 input 标签的 type 属性 */
    type?: string,

    /** 输入框内容 */
    value?: string,

    /** disabled */
    disabled?: boolean,

    /** placeholder 中的内容 */
    placeholder?: string,

    /** 初始值 */
    defaultValue?: string,

    /** 自动获取焦点 */
    autoFocus?: boolean,

    /** 控件大小。注：标准表单内的输入框大小限制为 large。可选 large default small */
    size?: 'large' | 'default' | 'small',

    /** 带前置标签的 input */
    addonBefore?: React.ReactNode,

    /** 带后置标签的 input */
    addonAfter?: React.ReactNode,

    /** 按下回车的回调 */
    onPressEnter?: React.KeyboardEventHandler<HTMLInputElement>,

    /** search 点击搜索或按下回车键时的回调 */
    onSearch?: (value: string, event?: React.MouseEvent<HTMLElement> | React.KeyboardEvent<HTMLInputElement>) => any,

    /** search  是否有确认按钮，可设为按钮文字 */
    enterButton?: boolean | React.ReactNode,

    rows?: number,

    /** 自定义width,height */
    defineStyle?: {},

    /** style */
    style?: {},
    
    /** 支持lable属性,此属性目前不再使用 */
    lableText?: string,

    /** 变化回调 */
    onChange?: (value: number | string | undefined) => void,

    /** 失去焦点的时回调 */
    onBlur?: (value?: any) => void;

    /** 获得焦点时回调 */
    onFocus?: () => void;

    /** 带有后缀图标的input */
    suffix?: string|React.ReactNode;

    /** 最小值 */
    min?: number,

    /** 最大值 */
    max?: number,

    /** 每次改变步数，可以为小数 */
    step?: number | string,

    /** 输入框是否要禁止输入空格 */
    space?: boolean,

    IInputNumberInterface?: IInputNumberInterface
    
}

export interface IInputNumberInterface {

    /** 最小值 */
    min?: number;

    /** 最大值 */
    max?: number;

    /** 当前值 */
    value?: number;

    /** 每次改变步数，可以为小数 */
    step?: number | string;

    /** 初始值 */
    defaultValue?: number;

    /** 变化回调 */
    onChange?: (value: number | string | undefined) => void;

    /** disabled */
    disabled?: boolean;

    /** 输入框大小 */
    size?: 'large' | 'small' | 'default';

    /** placeholder 中的内容 */
    placeholder?: string;

    /** 自定义width,height */
    defineStyle: {},

    /** style */
    style?: {},

    /** 组件id */
    id?: string,
    
    /** 组件class */
    className?: any
}






