### 1.变更记录

变更时间 | 变更版本 | 变更人 | 变更内容
:-: | :-: | :-: | :-: |
2018.12.01 | V0.0.1 | Gail | 新增Modal组件
2019.01.17 | V0.0.2 | Amber | 新增Modal组件点击蒙层是否允许关闭属性

<br><br/>
### 2.安装方式
<code>
npm install irs-modal
</code>

<br><br/><br><br/>
### 3. 调用方式
#### 基本组件格式

```jsx
class IrsButtonBasicDemo extends React.Component {
  constructor() {
    super()
    this.state = {
        visible: false
    }
    this.showModal = this.showModal.bind(this);
    this.onOk = this.onOk.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  showModal() {
    this.setState({visible: true});
  }
  onOk() {
    this.setState({visible: false});
  }
  onCancel() {
    this.setState({visible: false});
  }
  render() {
    return (
      <div className="App">
        <IrsButton onClick={this.showModal}>点击弹出</IrsButton>
        <IrsModal 
          title="基本弹出"
          visible={this.state.visible} 
          onOk={this.onOk} 
          onCancel={this.onCancel}
          content={<div>基本弹出框内容</div>} />
          
      </div>
    )
  }
}
;<IrsButtonBasicDemo />
```

#### 点击确定后异步关闭对话框，例如提交表单。

```jsx
class IrsButtonBasicDemo extends React.Component {
  constructor() {
    super()
    this.state = {
        visible: false,
        confirmLoading: false,
        ModalText:'异步关闭'
    }
    this.showModal = this.showModal.bind(this);
    this.onOk = this.onOk.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  showModal() {
    this.setState({visible: true});
  }
  onOk() {
    this.setState({
      ModalText: '弹框会在两秒后关闭',
      confirmLoading: true,
    });
    setTimeout(() => {
      this.setState({
        visible: false,
        confirmLoading: false,
      });
    }, 2000);
  }
  onCancel() {
    this.setState({visible: false});
  }
  render() {
    return (
      <div className="App">
        <IrsButton onClick={this.showModal}>点击弹出</IrsButton>
        <IrsModal 
          title="异步关闭"
          visible={this.state.visible} 
          onOk={this.onOk} 
          onCancel={this.onCancel}
          confirmLoading={this.state.confirmLoading}
          content={<div>{this.state.ModalText}</div>} />
      </div>
    )
  }
}
;<IrsButtonBasicDemo />
```

#### 自定义页脚, footer属性为null的时候，隐藏页脚。
```jsx
class IrsButtonBasicDemo extends React.Component {
  constructor() {
    super()
    this.state = {
        visible: false,
    }
    this.showModal = this.showModal.bind(this);
    this.onOk = this.onOk.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  showModal() {
    this.setState({visible: true});
  }
  onOk() {
    this.setState({ visible: false });
  }
  onCancel() {
    this.setState({visible: false});
  }
  render() {
    return (
      <div className="App">
        <IrsButton onClick={this.showModal}>点击弹出</IrsButton>
        <IrsModal 
          title="自定义页脚"
          visible={this.state.visible}
          confirmLoading={this.state.confirmLoading}
          footer={[
            <div>
              <IrsButton onClick={this.onOk}>自定义确认</IrsButton>
              <IrsButton onClick={this.onCancel}>自定义取消</IrsButton>
            </div>
          ]}
          content={<div>自定义页脚</div>} />
      </div>
    )
  }
}
;<IrsButtonBasicDemo />
```

#### 确认对话框，使用 IrsModal.default.modalFunc('confirm', {}) 可以快捷地弹出确认框，onCancel/onOk 返回 promise 可以延迟关闭，可自定义按钮文字。
#### 按钮类型有'default' | 'primary' | 'ghost' | 'dashed' | 'danger'，按钮可定义禁用属性
```jsx
  const IrsModal = require('./modal.tsx');
  console.log(IrsModal)
  showConfirm = () => {
    IrsModal.default.modalFunc('confirm', {
      title: 'Confirm',
      content: 'Bla bla ...',
      okText: '确认',
      cancelText: '取消',
      onOk() {
        return new Promise((resolve, reject) => {
          setTimeout(Math.random() > 0.5 ? resolve : reject, 1000);
        }).catch(() => console.log('Oops errors!'));
      },
    });
  }
  showConfirmDanger = () => {
    IrsModal.default.modalFunc('confirm', {
      title: 'ConfirmDanger',
      content: '确认警告',
      okType: 'danger',
      okText: '确认',
      cancelText: '取消'
    });
  }
  showConfirmDisabled = () => {
    IrsModal.default.modalFunc('confirm', {
      title: 'ConfirmDanger',
      content: '确认禁用',
      okText: '确认',
      cancelText: '取消',
      okButtonProps: {
        disabled: true,
      }
    });
  }
  <div className="App">
    <IrsButton onClick={this.showConfirm} style={{margin: '0 10px 0 0'}}>confirm</IrsButton>
    <IrsButton onClick={this.showConfirmDanger} style={{margin: '0 10px 0 0'}}>confirmDanger</IrsButton>
    <IrsButton onClick={this.showConfirmDisabled} style={{margin: '0 10px 0 0'}}>confirmDisabled</IrsButton>
  </div>
```

#### 信息提示：各种类型的信息提示，只提供一个按钮用于关闭。
```jsx
  const IrsModal = require('./modal.tsx');
  showInfo = () => {
    IrsModal.default.modalFunc('info', {
      title: 'This is a notification message',
      content: (
        <div>
          <p>some messages...some messages...</p>
          <p>some messages...some messages...</p>
        </div>
      ),
      onOk() {},
    });
  }
  showSuccess = () => {
    IrsModal.default.modalFunc('success', {
      title: 'This is a success message',
      content: 'some messages...some messages...',
    });
  }
  showError = () => {
    IrsModal.default.modalFunc('error', {
      title: 'This is an error message',
      content: 'some messages...some messages...',
    });
  }
  showWarning = () => {
    IrsModal.default.modalFunc('warning', {
      title: 'This is a warning message',
      content: 'some messages...some messages...',
    });
  }
  <div className="App">
    <IrsButton onClick={this.showInfo} style={{margin: '0 10px 0 0'}}>info</IrsButton>
    <IrsButton onClick={this.showSuccess} style={{margin: '0 10px 0 0'}}>success</IrsButton>
    <IrsButton onClick={this.showError} style={{margin: '0 10px 0 0'}}>error</IrsButton>
    <IrsButton onClick={this.showWarning} style={{margin: '0 10px 0 0'}}>warning</IrsButton>
  </div>
```








