// import * as React from 'react';
// import { AbstractSelectProps, SelectProps } from 'antd/lib/select/index'
export declare type SelectValue = string | string[] | number | number[] | ILabeledValue | ILabeledValue[];

export interface ISelectInterface {

    /** 指定当前选中的条目 */
    value?: string|string[]|number|number[];

    /** 默认获取焦点 */
    autoFocus?: boolean;

    /** 支持清除 */
    allowClear: boolean;

    /** 是否默认高亮第一个选项。 */
    defaultActiveFirstOption?: boolean;

    /** 指定默认选中的条目 */
    defaultValue?: SelectValue;

    /** 是否禁用 */
    disabled?: boolean;
    
    /** 下拉菜单和选择器同宽 */
    dropdownMatchSelectWidth?: boolean;

    /** 当下拉列表为空时显示的内容 */
    notFoundContent?: string;

    /** 选择框默认文字 */
    placeholder?: string | React.ReactNode;

    /** 是否显示下拉小箭头 */
    showArrow?: boolean;

    /** 使单选模式可搜索 */
    showSearch?: boolean;

    /** 选择框大小，可选 large small */
    size?: 'default' | 'large' | 'small';

    /** 自定义的选择框后缀图标 */
    suffixIcon?: React.ReactNode;

    /** 选中 option，或 input 的 value 变化（combobox 模式下）时，调用此函数 */
    // tslint:disable-next-line:array-type
    onChange?: (value: SelectValue, option: React.ReactElement<any> | React.ReactElement<any>[]) => void;

    /** 文本框值变化时回调 */
    onSearch?: (value: string) => any;

    /** 被选中时调用，参数为选中项的 value (或 key) 值 */
    onSelect?: (value: SelectValue, option: React.ReactElement<any>) => any;

    /** 是否默认展开下拉菜单 */
    defaultOpen?: boolean;

    /** 展开下拉菜单的回调 */
    onDropdownVisibleChange?: (open: boolean) => void;    

    /** 加载中状态 */
    // loading?: boolean

    /** Option 配置项 */
    options?: string[]

    /** 搜索时过滤对应的 option 属性，如设置为 children 表示对内嵌内容进行搜索 */
    optionFilterProp?: string;

    /** 是否根据输入项进行筛选。当其为一个函数时，会接收 inputValue option 两个参数，当 option 符合筛选条件时，应返回 true，反之则返回 false。 */
    filterOption?: boolean | ((inputValue: string, option: React.ReactElement<IOptionProps>) => any);

    /** 失去焦点的时回调 */
    onBlur?: (value: SelectValue) => void;

    /** 获得焦点时回调 */
    onFocus?: () => void;

    /** 定义select 样式 */
    style?:React.CSSProperties;

    /** 支持lable属性 */
    lableText?: string,

    /** 自定义 options */
    types?: boolean

    /** options 数组，里面放置的option标签 */
    optionChild?: []
}

export interface ILabeledValue {
    key: string;
    label: React.ReactNode;
}

export interface IOptionProps {
    disabled?: boolean;
    value?: string | number;
    title?: string;
    children?: React.ReactNode;
    className?: string;
    key?: string;
    style?: React.CSSProperties;
}