export declare type TabsType = 'line' | 'card' | 'editable-card';
export declare type TabsPosition = 'top' | 'right' | 'bottom' | 'left';

export interface IrsTabModel {
    /** tab的标题 */
    title: string;

    /** 对应 activeKey 必须传 */
    key: string;

    /** 提醒的条数 (count) 为0是不显示 */
    count?: number;

    /** 提醒的条数 (count) 的类名 */
    countClassName?: string;

    /** 自定义title右侧的控件· */
    rightRender?: () => React.ReactNode;

    /** 前置icon */
    icon?: string;

    /** 前置icon theme */
    iconTheme?: string;

    /** 仅适用双色图标。设置双色图标的主要颜色 */
    twoToneColor?: string;

    /** 显示删除按钮 默认false为true时type为editable-card生效 */
    closable?: boolean;

    /** disable 默认false */
    disable?: boolean;

    /** tab头自定义 有此属性  上述 title count icon rightRender 都无效 */
    tabRender?: () => React.ReactNode;

    /** 对应tab 显示的视图 */
    render?: (index: any) => React.ReactNode;
}

export interface IPropsInterface {
    /** id */
    id?: string;

    /** style */
    style?: any;

    /** className */
    className?: string;

    /** tab 的数组 */
    tabData: IrsTabModel[];

    /** 页签的基本样式，可选 line、card、editable-card 类型  默认为card */
    type?: TabsType;

    /** 默认激活 tab 面板的 key  当activeKey有值时 defaultActiveKey 失效 */
    defaultActiveKey: string;

    /** 当前激活 tab 面板的 key */
    activeKey?: string;

    /** 大小，提供 large default 和 small 三种大小 */
    size?: 'large' | 'default' | 'small';

    /** tabs 之间的间隙 */
    tabBarGutter?: number;

    /** 页签位置，可选值有 top right bottom left */
    tabPosition?: TabsPosition;

    /** 隐藏新增按钮 默认false */
    hideAdd: boolean;

    /** 是否使用动画切换 Tabs，在 tabPosition=top|bottom 时有效 默认false */
    animated?: boolean | {
        inkBar: boolean;
        tabPane: boolean;
    };

    /** 切换面板的回调 */
    onChange?: (activeKey: string) => void;

    /** 新增和删除页签的回调，在 type="editable-card" 时有效    (targetKey, action): void */
    onEdit?: (targetKey: string | React.MouseEvent<HTMLElement>, action: any) => void;

    /** tab 被点击的回调 */
    onTabClick?: () => void;

    /** prev 按钮被点击的回调 */
    onPrevClick?: React.MouseEventHandler<any>;

    /** next 按钮被点击的回调 */
    onNextClick?: React.MouseEventHandler<any>;

    /** 替换TabBar，用于二次封装标签头 (props: DefaultTabBarProps, DefaultTabBar: React.ReactNode) => React.ReactNode */
    renderTabBar?: (props: IPropsInterface, DefaultTabBar: React.ReactNode) => React.ReactElement<any>;
}

