import { SpinProps } from 'antd/lib/spin';
export declare type SortOrder = 'descend' | 'ascend';
export declare type TableSize = 'default' | 'middle' | 'small';
export declare type RowSelectionType = 'checkbox' | 'radio';
export declare type TableSelectWay = 'onSelect' | 'onSelectMultiple' | 'onSelectAll' | 'onSelectInvert';

export declare type SelectionItemSelectFn = (key: string[]) => any;
export declare type CompareFn = ((a: any, b: any, sortOrder?: SortOrder) => number);
export declare type SelectionSelectFn = (record: any, selected: boolean, selectedRows: object[], nativeEvent: Event) => any;

export interface IrsSelectDataProps {
    /** name */
    name: string;

    /** id */
    id: string,

    /** disabled 默认false */
    disabled: boolean,
}

export interface IrsTableSortProps {
    /** sort控件的类型 默认为 Input */
    sortType?: 'Input' | 'TimePicker' | 'Select' | 'SelectSerarch' | 'Custom';

    /** select的所有值的数组 */
    selectArray?: IrsSelectDataProps[];

    /** sortType 为 SelectSerarch 搜索的方法 */
    selectOnSerarch?: (item: any, searchText: any) => any;

    /** sortType 为 Custom时 自定义控件 */
    sortCustomView?: (record: any) => React.ReactNode;

    /** 是否不可用 */
    disabled?: boolean;

    /** fixed  boolean | ('left' | 'right') */
    fixed?: boolean | ('left' | 'right');

    /** placeholder  默认请输入 */
    placeholder?: string;

    /** 默认值 只有第一次设置有效 后面改无效 */
    defaultValue?: string;
}

export interface IrsColumnFilterItem {
    /** text */
    text: string;

    /** valye */
    value: string;

    /** children */
    children?: IrsColumnFilterItem[];
};

export interface IrsSelectionItem {
    /** key */
    key: string;

    /** text */
    text: React.ReactNode;

    /** onSelect */
    onSelect: SelectionItemSelectFn;
}

export interface IrsTableStateFilters {
    /** [key: string] */
    [key: string]: string[];
}

export interface IrsTableColumnProps {
    /** 列头显示文字  ReactNode|({ sortOrder, filters }) => ReactNode */
    title?: React.ReactNode | ((options: {
        filters: IrsTableStateFilters;
        sortOrder?: SortOrder;
    }) => React.ReactNode);

    /** 列数据在数据项中对应的  key，支持 a.b.c、a[0].b.c[1] 的嵌套写法  唯一性 */
    dataIndex: string;

    /** 设置列内容的对齐方式 默认left */
    align?: 'left' | 'right' | 'center';

    /** 列的 className */
    className?: string;

    /** 表头列合并,设置为 0 时，不渲染 */
    colSpan?: number;

    /** 默认排序顺序 'ascend' | 'descend' */
    defaultSortOrder?: SortOrder;

    /** 可以自定义筛选菜单，此函数只负责渲染图层，需要自行编写各种交互 */
    filterDropdown?: React.ReactNode | ((props: object) => React.ReactNode);

    /** 用于控制自定义筛选菜单是否可见 */
    filterDropdownVisible?: boolean;

    /** 标识数据是否经过过滤，筛选图标会高亮 默认false */
    filtered?: boolean;

    /** 筛选的受控属性，外界可用此控制列的筛选状态，值为已筛选的 value 数组 */
    filteredValue?: any[];

    /** 自定义 filter 图标  类型:ReactNode|(filtered: boolean) => ReactNode   默认false */
    filterIcon?: React.ReactNode | ((filtered: boolean) => React.ReactNode);

    /** 是否多选 默认true */
    filterMultiple?: boolean;

    /** 表头的筛选菜单项 */
    filters?: IrsColumnFilterItem[];

    /** 列是否固定，可选 true(等效于 left) 'left' 'right' */
    fixed?: boolean | ('left' | 'right');

    /** React 需要的 key，如果已经设置了唯一的 dataIndex，可以忽略这个属性 */
    key?: string;

    /** 生成复杂数据的渲染函数，参数分别为当前行的值，当前行数据，行索引，@return里面可以设置表格行/列合并 */
    render?: (text: any, record: any, index: number) => React.ReactNode;

    /** 排序函数，本地排序使用一个函数(参考 Array.sort 的 compareFunction)，需要服务端排序可设为 true  默认为true */
    sorter?: boolean | CompareFn;

    /** 排序的受控属性，外界可用此控制列的排序，可设置为 'ascend' 'descend' false */
    sortOrder?: SortOrder;

    /** 列宽度 */
    width?: string | number;

    /** 设置单元格属性	Function(record, rowIndex) */
    onCell?: (record: any) => any;

    /** 本地模式下，确定筛选的运行函数  一般不用本地排序 */
    onFilter?: (value: any, record: any) => boolean;

    /** 自定义筛选菜单可见变化时调用   function(visible) {} */
    onFilterDropdownVisibleChange?: (visible: boolean) => void;

    /** 设置头部单元格属性 */
    onHeaderCell?: (props: IrsTableColumnProps) => any;

    /** 是否有排序控件 默认false */
    canFilter?: boolean;

    /** 默认false  render有值时 该值不生效 */
    needToolTip?: boolean;

    /** 下拉筛选的配置 */
    tableFilter?: IrsTableSortProps;

    /** 二级菜单为清理filter条件的按钮 */
    showClearFilter?: boolean;
}

export interface IrsSorterResult {
    /** 排序 descend  ascend */
    order: SortOrder;

    /** 字段名称 */
    field: string;

    /** 对应的dataIndex */
    columnKey: string;
}

export interface IrsFilterResult {
    /** 对应的dataIndex */
    dataIndex: string;
    /** 对应的dataIndex的 data */
    data: any;
    /** 对应的值 */
    value: any;
}

export interface IrsTableRowSelection {
    /** 多选/单选，checkbox or radio  默认 checkbox */
    type?: RowSelectionType;

    /** 指定选中项的 key 数组，需要和 onChange 进行配合 */
    selectedRowKeys?: string[];

    /** 选中项发生变化时的回调 Function(selectedRowKeys, selectedRows) */
    onChange?: (selectedRowKeys: string[] | number[], selectedRows: object[]) => void;

    /** 选择框的默认属性配置  Function(record) */
    getCheckboxProps?: (record: any) => object;

    /** 用户手动选择/取消选择某行的回调 Function(record, selected, selectedRows, nativeEvent) */
    onSelect?: SelectionSelectFn;

    // onSelectMultiple?: (selected: boolean, selectedRows: Object[], changeRows: Object[]) => void;

    // 用户手动选择/取消选择所有行的回调  Function(selected, selectedRows, changeRows)
    onSelectAll?: (selected: boolean, selectedRows: object[], changeRows: object[]) => void;

    /** 用户手动选择反选的回调 Function(selectedRowKeys: string[] | number[]) */
    onSelectInvert?: (selectedRowKeys: string[] | number[]) => void;

    /** 自定义选择项 配置项, 设为 true 时使用默认选择项  默认true */
    selections?: IrsSelectionItem[] | boolean;

    /** 去掉『全选』『反选』两个默认选项  默认false */
    hideDefaultSelections?: boolean;

    /** 把选择框列固定在左边 */
    fixed?: boolean;

    /** 自定义列表选择框宽度 */
    columnWidth?: string | number;

    /** 指定选中项的 key 数组，需要和 onChange 进行配合 */
    selectWay?: TableSelectWay;

    /** 自定义列表选择框标题 */
    columnTitle?: string | React.ReactNode;
}


export interface IPropsInterface { //extends TableProps<any>
    /** 设置横向或纵向滚动，也可用于指定滚动区域的宽和高，建议为 x 设置一个数字，如果要设置为 true，需要配合样式 .ant-table td { white-space: nowrap; } */
    scroll?: {
        x?: boolean | number | string;
        y?: boolean | number | string;
    };

    /** id */
    id?: string;

    /** style */
    style?: any;

    /** className */
    className?: string;

    /** 是否展示外边框和列边框 */
    bordered?: boolean;

    /** 表格列的配置描述 具体见 TableColumnProps属性 */
    columns: IrsTableColumnProps[];

    /** 页面是否加载中 默认false */
    loading?: boolean | SpinProps;

    /** 表格行的类名  Function(record, index):string */
    rowClassName?: (record: any, index: number) => string;

    /** 数据数组 */
    dataSource: any[];

    /** 正常或迷你类型，default or small */
    size?: TableSize;

    /** 表格行 key 的取值，可以是字符串或一个函数 默认Key */
    rowKey?: string | ((record: any, index: number) => string);

    /** 表格行是否可选择 */
    rowSelection?: IrsTableRowSelection;

    /** 是否显示表头 默认True */
    showHeader?: boolean;

    /** 表格尾部 */
    footer?: (currentPageData: object[]) => React.ReactNode;

    /** 表格标题 */
    title?: ((currentPageData: object[]) => React.ReactNode);

    /** 点击展开图标时触发 Function(expanded, record) */
    onExpand?: (expanded: boolean, record: any) => void;

    /** 展开的行变化时触发 Function(expandedRows) */
    onExpandedRowsChange?: (expandedRowKeys: string[] | number[]) => void;

    /** 设置头部行属性 Function(column, index) */
    onHeaderRow?: (columns: IrsTableColumnProps[], index: number) => any;

    /** 设置行属性 Function(record, index) */
    onRow?: (record: any, index: number) => any;

    /** 是否展示筛选 默认false */
    showFilter?: boolean;

    /** 配置筛选清除的Icon */
    filterIconRender?: ()=> React.ReactNode;

    /** 自定义筛选清除按钮 */
    filterClearRender?: () => React.ReactNode;

    /** 清除筛选条件(自定义筛选的需自己清除)请在触发clearFliterData回调时设置改值为false,避免不必要的渲染 */
    shouldClearFilter?: boolean;

    /** 排序的回调 */
    onChange?: (sorter: IrsSorterResult) => void;

    /** 筛选触发的回调(自定义筛选的需自己取值) */
    filterChange?: (sort: IrsFilterResult[]) => any;

    /** 筛选框 清空的回调 */
    clearFliterData?: () => any;
}
