/**
 * The only true table.
 * @date 2018.12.01
 * @version 0.0.1
 * @author Kang
 */
import * as React from 'react';
import * as module from './module';
import './style.less';
import { Table, Icon, Tooltip, } from 'antd';
import { others } from 'fit-transmit-transparently';

import IrsInput from '../../irs-input';
import IrsSelect from '../../irs-select';
import IrsDatePicker from '../../irs-datepicker';

import { Resizable } from 'react-resizable';

// const Option = Select.Option;

const filterStyle = {
    width: '100%',
    height: '30px'
}


const ResizeableTitle = (props: any) => {
    const { onResize, width, ...restProps } = props;

    if (!width) {
        return <th {...restProps} />;
    }

    return (
        <Resizable width={width} height={0} onResize={onResize}>
            <th {...restProps} />
        </Resizable>
    );
};


class IrsTable extends React.Component<module.IPropsInterface, any> {

    static defaultProps = {
        loading: false,
        rowClassName: '',
        size: 'default',
        bordered: false,
        rowKey: 'key',
        showHeader: true,
        pagination: false,
        showFilter: false,
        shouldClearFilter: false,
    }

    // static resizeComponents = {
    //     header: {
    //       cell: ResizeableTitle
    //     }
    // };

    static components = {
        header: {
            cell: ResizeableTitle
        }
     }


    constructor(props: module.IPropsInterface) {
        super(props);
        this.state = {
            refDic: [],
            propsData: {},
            key: 0
        }
        this.setSortChildren = this.setSortChildren.bind(this);
        this.onInputValueChange = this.onInputValueChange.bind(this);
        this.fixData = this.fixData.bind(this);
        this.selectValueChange = this.selectValueChange.bind(this);
        this.selectSerarchValueChange = this.selectSerarchValueChange.bind(this);
        this.dataPickerValueChange = this.dataPickerValueChange.bind(this);
        this.sortValueChanged = this.sortValueChanged.bind(this);
        this.getSortValue = this.getSortValue.bind(this);
        this.setSortValue = this.setSortValue.bind(this);
        this.tableOnChange = this.tableOnChange.bind(this);
        this.clearFliterData = this.clearFliterData.bind(this);
        this.hasLeftFixedField = this.hasLeftFixedField.bind(this);
        this.hasLeftFixedField = this.hasLeftFixedField.bind(this);
    }

    // input 值变化
    onInputValueChange(item: any, event: any) {
        this.setSortValue(item.dataIndex, event.target.value)
    }
    // input 按回车
    inputPressEnter(item: any, event: any) {
        this.sortValueChanged()
    }

    // select onserch 变化
    selectSerarchValueChange(item: any, text: any) {
        if (item.selectOnSerarch) {
            item.selectOnSerarch(item, text)
        }
    }

    //select值变化
    selectValueChange(item: any, value: any) {
        this.setSortValue(item.dataIndex, value)
        this.sortValueChanged()
    }

    // dataPicker值
    dataPickerValueChange(item: any, date: any, dateString: string) {
        this.setSortValue(item.dataIndex, date, dateString)
        this.sortValueChanged();
    }

    // 筛选 赋值
    setSortValue(dataIndex: string, value: any, time?: any) {

        const refDic = this.state.refDic

        refDic[dataIndex].value = value
        if (time) {
            refDic[dataIndex].time = time
        }

        this.setState({
            refDic,
        }, () => {
            const propsData = this.state.propsData

            this.fixData(propsData)

            this.setState({
                propsData
            })
        })
    }

    setSortDefaultValue = (item: any) => {
        const refDic = this.state.refDic
        if (!refDic[item.dataIndex]) {
            const refModel = {
                item,
                value: '',
                hidden: false,
                defaultValue: item.tableFilter.defaultValue,
            }
            refDic[item.dataIndex] = refModel
            //不需要重新渲染视图
            // this.setState({
            //     refDic
            // })
        }
    }

    // 获取对应的值
    getSortValue(dataIndex: string) {
        const refDic = this.state.refDic

        if (refDic[dataIndex]) {
            if (refDic[dataIndex].value) {
                return refDic[dataIndex].value
            }
        }
        return undefined
    }

    // 获取默认值
    getSortDefaultValue = (dataIndex: string) => {
        const refDic = this.state.refDic
        if (refDic[dataIndex]) {
            if (refDic[dataIndex].defaultValue) {
                return refDic[dataIndex].defaultValue
            }
        }
        return undefined
    }

    //触发 变化
    sortValueChanged() {

        const filter: any[] = []
        const dataIndex = 'dataIndex'
        const data = 'item'
        const value = 'value'

        for (const field in this.state.refDic) {
            if (field) {
                const item = {}
                item[dataIndex] = field
                item[data] = this.state.refDic[field].item
                item[value] = this.state.refDic[field].value
                filter.push(item)
            }
        }
        if (this.props.filterChange) {
            this.props.filterChange(filter)
        }
    }

    // 清理筛选头
    clearFliterData() {
        const refDic = this.state.refDic
        for (const field in refDic) {
            if (field) {
                refDic[field].value = ''
            }
        }

        this.setState({
            refDic
        }, () => {
            const propsData = this.state.propsData
            this.fixData(propsData)
            this.setState({
                propsData
            })
        })

        if (this.props.clearFliterData) {
            this.props.clearFliterData()
        }
    }

    // 设置不同类型的筛选表头
    setSortChildren(item: any) {

        let type = 'Input';
        let selectArray: any = [];
        let width = item.width;
        let align = item.align;
        let disabled = false;
        let className = 'irsTable-second-class';
        if (item.className) {
            className = 'irsTable-second-class, ' + className
        }
        if (item.tableFilter) {
            if (item.tableFilter.sortType) {
                type = item.tableFilter.sortType
            }
            if (item.tableFilter.selectArray) {
                selectArray = item.tableFilter.selectArray
            }
            if (item.tableFilter.width) {
                width = item.tableFilter.width
            }
            if (item.tableFilter.align) {
                align = item.tableFilter.align
            }
            if (item.tableFilter.disabled) {
                disabled = item.tableFilter.disabled
            }
            if (item.tableFilter.className) {
                className = 'irsTable-second-class, ' + item.tableFilter.className
            }
        }

        if (item.showClearFilter) {
            const childrenData = [
                {
                    title: (
                        <span>
                            {
                                this.props.filterClearRender ? this.props.filterClearRender() :
                                    <div onClick={this.clearFliterData} className="irsTable-filterClearContiner">
                                        {
                                            this.props.filterIconRender ? this.props.filterIconRender() : <Icon className={this.props.size === 'default' ? 'irsTable-Icon-default' : 'irsTable-Icon-small'}
                                                type="delete" />
                                        }
                                    </div>
                            }
                        </span>
                    ),
                    dataIndex: item.dataIndex,
                    key: item.dataIndex,
                    width,
                    className,
                    align,
                    render: item.render
                }
            ]
            return childrenData
        } else {
            if (item.canFilter) {

                if (type === 'Input') {

                    return [
                        {
                            title: <IrsInput placeholder={item.placeholder ? item.placeholder : '请输入'} disabled={disabled} defaultValue={this.getSortDefaultValue(item.dataIndex)} style={filterStyle} onPressEnter={this.inputPressEnter.bind(this, item)}
                                key={item.dataIndex} onChange={this.onInputValueChange.bind(this, item)} />,
                            dataIndex: item.dataIndex,
                            key: item.dataIndex,
                            width,
                            className,
                            align,
                            render: item.render
                        }
                    ]

                } else if (type === 'Select') {

                    const optionArr: any[] = []

                    selectArray.map((item1: any, index: any) => {
                        optionArr.push({
                            value: item1.id,
                            text: item1.name,
                            disabled: item1.disabled,
                        })
                    })

                    return [
                        {
                            title: (
                                <IrsSelect placeholder={item.placeholder ? item.placeholder : '请输入'} defaultValue={this.getSortDefaultValue(item.dataIndex)} disabled={disabled} value={this.getSortValue(item.dataIndex)}
                                    style={filterStyle} allowClear={true} onChange={this.selectValueChange.bind(this, item)} options={optionArr} />
                            ),
                            dataIndex: item.dataIndex,
                            key: item.dataIndex,
                            width,
                            className,
                            align,
                            render: item.render
                        }
                    ]

                } else if (type === 'SelectSerarch') {

                    const optionArr: any[] = []

                    selectArray.map((item1: any, index: any) => {
                        optionArr.push({
                            value: item1.id,
                            text: item1.name,
                            disabled: item1.disabled,
                        })
                    })

                    return [
                        {
                            title: (
                                <IrsSelect placeholder={item.placeholder ? item.placeholder : '请输入'} defaultValue={this.getSortDefaultValue(item.dataIndex)} disabled={disabled} value={this.getSortValue(item.dataIndex)} showSearch={true}
                                    onSearch={this.selectSerarchValueChange.bind(this, item)}
                                    onChange={this.selectValueChange.bind(this, item)}
                                    style={filterStyle} allowClear={true}
                                    showArrow={false} options={optionArr}
                                />
                            ),
                            dataIndex: item.dataIndex,
                            key: item.dataIndex,
                            width,
                            className,
                            align,
                            render: item.render
                        }
                    ]

                } else if (type === 'TimePicker') {

                    return [
                        {
                            title: (
                                <IrsDatePicker placeholder={item.placeholder ? item.placeholder : '请输入'} defaultValue={this.getSortDefaultValue(item.dataIndex)} type="datepicker" disabled={disabled} value={this.getSortValue(item.dataIndex)}
                                    onChange={this.dataPickerValueChange.bind(this, item)} style={filterStyle} />
                            ),
                            dataIndex: item.dataIndex,
                            key: item.dataIndex,
                            width,
                            align,
                            className,
                            render: item.render
                        }
                    ]

                } else if (type === 'Custom') {

                    return [
                        {
                            dataIndex: item.dataIndex,
                            key: item.dataIndex,
                            width,
                            align,
                            className,
                            title: item.tableFilter.sortCustomView(item),
                            render: item.render
                        }
                    ]
                }
            }
            return [
                {
                    title: <span style={filterStyle}/>,
                    dataIndex: item.dataIndex,
                    key: item.dataIndex,
                    width,
                    align,
                    className,
                    render: item.render
                }
            ]
        }
    }

    // 设置默认数据
    fixData(props: any) {
        if (props) {
            const columns = props.columns

            if (columns) {
                columns.map((item: any, index: any) => {

                    if (!item.key) {
                        item.key = item.dataIndex
                    }

                    if (!item.align) {
                        item.align = 'left'
                    }

                    if (item.sorter === undefined) {
                        item.sorter = true
                    }

                    if (!item.render && item.needToolTip) {
                        //Tooltip
                        item.render = (text: any, record: any, index1: any) => {
                            const obj = {
                                children: (<Tooltip title={text}> {text} </Tooltip>)
                            };
                            return obj;
                        }
                    }

                    // 初始化筛选条件的对象
                    if(!this.state.refDic[item.dataIndex] && item.tableFilter) {
                        this.setSortDefaultValue(item)
                    }

                    const sortStatus = props.showFilter

                    if (sortStatus) { // 可以筛选
                        item.children = this.setSortChildren(item)
                    } else { // 不能筛选
                        delete item.children
                    }
                })

            }
        }
    }

    componentWillMount() {
        const propsData = this.props
        this.fixData(propsData)
        this.setState({
            propsData
        })
    }

    componentWillReceiveProps(nextProps: any) {
        if (nextProps !== this.props) {
            const propsData = nextProps
            this.fixData(propsData)
            this.setState({
                propsData
            })
            if (nextProps.shouldClearFilter === true) {
                this.clearFliterData()
            }
        }
    }

    tableOnChange(pagination: any, filters: any, sorter: any) {
        if (this.props.onChange) {
            delete sorter.column
            this.props.onChange(sorter)
        }
    }

    hasLeftFixedField() {
        let hasFixed = false;
        this.state.propsData.columns.map((item: any) => {
            if (item.fixed === 'left') {
                hasFixed = true
            }
        })
        return hasFixed
    }

    getContinerClassName() {
        const hasFixedField = this.hasLeftFixedField()

        if (this.props.rowSelection) {
            if (!hasFixedField) {
                return "irs-table-continer"
            }
        }
        return "irs-table-continer-Important"
    }

    handleResize(index: any) {
        return (e: any, size: any) => {

            const nextColumns = this.state.propsData.columns;
            nextColumns[index] = {
                ...nextColumns[index],
                width: size.size.width
            };

            this.setState({
                propsData: this.state.propsData
            })
            return {};
        };
    }

    render() {

        others(IrsTable.defaultProps, this.props);

        const continerClassName = this.getContinerClassName();


        const columns = this.state.propsData.columns.map((col: any, index: any) => ({
            ...col,
            onHeaderCell: (column: any) => ({
                width: column.width,
                onResize: this.handleResize(index),
            }),
        }));

        return (
            <div className={continerClassName}>
                <Table
                    {...this.props}
                    components={IrsTable.components}
                    scroll={this.props.scroll}
                    columns={columns}
                    loading={this.props.loading}
                    rowClassName={this.props.rowClassName}
                    dataSource={this.props.dataSource}
                    size={this.props.size}
                    rowKey={this.props.rowKey}
                    rowSelection={this.props.rowSelection}
                    showHeader={this.props.showHeader}
                    footer={this.props.footer}
                    title={this.props.title}
                    onExpand={this.props.onExpand}
                    onExpandedRowsChange={this.props.onExpandedRowsChange}
                    onHeaderRow={this.props.onHeaderRow}
                    onRow={this.props.onRow}
                    pagination={false}
                    onChange={this.tableOnChange}
                />
            </div>
        )
    }
}

export default IrsTable;
