// import * as React from 'react';
// import { } from 'antd/lib/Upload';
export declare type UploadListType = 'text' | 'picture' | 'picture-card';
export declare type UploadFileStatus = 'error' | 'success' | 'done' | 'uploading' | 'removed';

export interface IrsUploadFile {
    uid: string;
    size: number;
    name: string;
    fileName?: string;
    lastModified?: number;
    lastModifiedDate?: Date;
    url?: string;
    status?: UploadFileStatus;
    percent?: number;
    thumbUrl?: string;
    originFileObj?: File;
    response?: any;
    error?: any;
    linkProps?: any;
    type: string;
}

export interface IrsRcFile extends File {
    uid: string;
    lastModifiedDate: Date;
}

export interface IrsHttpRequestHeader {
    [key: string]: string;
}

export interface IrsShowUploadListInterface {
    showRemoveIcon?: boolean;
    showPreviewIcon?: boolean;
}

export interface IrsUploadChangeParam {
    file: IrsUploadFile;
    fileList: IrsUploadFile[];
    event?: {
        percent: number;
    };
}

export interface IPropsInterface {

    /** id */
    id?: string;

    /** style */
    style?: any;

    /** className */
    className?: string;

    /** 样式 appearanceStyle为 PicLoad时 listType="picture-card"  maxCount生效  appearanceStyle为 FileLoad title subTitle时生效" */
    appearanceStyle?: 'PicLoad' | 'FileLoad' | 'UploadButton' | 'Upload' | 'Dragger'

    /** 上传列表的内建样式，支持三种基本样式 text, picture 和 picture-card 默认 text */
    listType?: UploadListType

    /** 接受上传的文件类型 */
    accept?: string;

    /** 上传的地址 */
    action?: string | ((file: IrsUploadFile) => PromiseLike<any>);

    /** 支持上传文件夹 默认false */
    directory?: boolean;

    /** 上传文件之前的钩子，参数为上传的文件，若返回 false 则停止上传。支持返回一个 Promise 对象，Promise 对象 reject 时则停止上传，resolve 时开始上传（ resolve 传入 File 或 Blob 对象则上传 resolve 传入对象）。注意：IE9 不支持该方法。 */
    beforeUpload?: (file: IrsRcFile, FileList: IrsRcFile[]) => boolean | PromiseLike<any>;

    /** 上传所需参数或返回上传参数的方法 */
    data?: object | ((file: IrsUploadFile) => any);

    /** 默认已经上传的文件列表 */
    defaultFileList?: IrsUploadFile[];

    /** 是否禁用 默认false */
    disabled?: boolean;

    /** 已经上传的文件列表（受控） */
    fileList?: IrsUploadFile[];

    /** 设置上传的请求头部，IE10 以上有效 */
    headers?: IrsHttpRequestHeader;

    /** 是否支持多选文件，ie10+ 支持。开启后按住 ctrl 可选择多个文件。默认false */
    multiple?: boolean;

    /** 发到后台的文件参数名 默认 file */
    name?: string;

    /** 是否展示 uploadList, 可设为一个对象，用于单独设定 showPreviewIcon 和 showRemoveIcon 默认true */
    showUploadList?: boolean | IrsShowUploadListInterface;

    /** 服务端渲染时需要打开这个 默认false */
    supportServerRender?: boolean;

    /** 上传请求时是否携带 cookie  默认false */
    withCredentials?: boolean;

    /** 点击打开文件对话框 默认true */
    openFileDialogOnClick?: boolean;

    /** 上传文件改变时的状态 */
    onChange?: (info: IrsUploadChangeParam) => void;

    /** 点击文件链接或预览图标时的回调 */
    onPreview?: (file: IrsUploadFile) => void;

    /** 点击移除文件时的回调，返回值为 false 时不移除。支持返回一个 Promise 对象，Promise 对象 resolve(false) 或 reject 时不移除。 */
    onRemove?: (file: IrsUploadFile) => void | boolean;

    /** appearanceStyle为 PicLoad时生效  最大上传数量 默认1 */
    maxCount?: number;

    /** appearanceStyle为 FileLoad生效 默认Click or drag file to this area to upload */
    title?: string;

    /** appearanceStyle为 FileLoad生效 默认Support for a single or bulk upload. Strictly prohibit from uploading company data or other band files */
    subTitle?: string;
}

