/**
 * @component constants
 * @description Http 服务
 * @time 2018/05/09
 * @author Mike.Cai
 */
import { IrsMessage } from '../../../index';

export class IrsFetchHttp {
    [x: string]: any;
    contentType: string;
    credentials: string;
    mode: string;
    headers: any;
    data: any;

    constructor() {
        this.contentType = "application/json;charset=UTF-8";
        this.credentials = "include";
        this.mode = "cors";
    }

    handlerErr(e: any, url: any): any {
        // console.log("捕获handlerErr中的异常信息弹框提示处理");
        IrsMessage.messageFun('error', '服务异常，请稍后重试！');
        return Promise.reject("网络异常，请稍后重试！" + url);
    }

    async fetchData(url: string, reqtype: string, options?: any, file?: any, payload?: any) { //默认'json'，文本传值‘text’
        // 本地调试阶段开启cookie
        if (process.env.NODE_ENV === 'development') {
            document.cookie = process.env.REACT_APP_COOKIE as any;
        }

        if (payload === 'json') {
            this.headers = {
                'Accept': 'application/json, text/plain, */*',
                'Content-Type': (!file ? 'application/json' : 'multipart/form-data'),
                'X-Requested-With': 'XMLHttpRequest'
            }
        } else {
            this.headers = {
                'Accept': 'application/json, text/plain, */*',
                'Content-Type': (!file ? 'application/json' : 'multipart/form-data'),
                'authorization': 'authorization-text',
                'X-Requested-With': 'XMLHttpRequest'
            }
        }

        if (reqtype === 'get') {
            this.data = {
                method: reqtype,
                headers: {
                    'Accept': 'application/json, text/plain, */*',
                    'Content-Type': 'application/json',
                    'X-Requested-With': 'XMLHttpRequest'
                },
                credentials: this.credentials as any
            }
        } else {
            this.data = {
                method: reqtype,
                headers: this.headers,
                credentials: this.credentials as any,
                // 接口不规范，body结构不为json，做特殊处理
                // body: (reqtype === "post" ? JSON.stringify(options) : null as any)
                // body: (reqtype === "get" ? "" : (url === '/web/flexible/codeValue/list.do' || payload === 'text' ? JSON.stringify(options) : options))
                body: (reqtype === "get" ? "" : (payload === 'text' ? options : JSON.stringify(options)))
            }
        }

        try {
            const response = await fetch(url, this.data).catch(e => this.handlerErr(e, url));
            if (!response.ok) {
                if (response.status === 401) {
                    //登录信息过期
                    IrsMessage.messageFun('error', '服务异常');
                    if (process.env.NODE_ENV === 'production') {
                        if (window.top) {
                            window.top.location.href = location.origin + "/gateway/pre_logout";
                        } else {
                            location.href = location.origin + "/gateway/pre_logout";
                        }
                    }
                } else if (response.status === 403) {
                    //无权限
                    IrsMessage.messageFun('error', '服务异常，请稍后重试！');
                } else {
                    //4XX 5XX其它异常统一弹框提示处理
                    if(response.status === 500) {
                        return response;
                    } else {
                        IrsMessage.messageFun('error', '服务异常，请稍后重试！');
                    }
                }
            }
            return response;
        } catch (error) {
            IrsMessage.messageFun('error', '服务异常，请稍后重试！');
        }

    }


    get(url: string, options: any) {
        const fetchUrl = this.serializeParme(url, options);
        return this.fetchData(fetchUrl, 'get', {}).then(d => d.json()).catch(e => console.log(e));
    }

    post(url: string, options: any, file = false, payload = 'json') {
        return this.fetchData(url, 'post', options, file, payload).then(d => d.json()).catch(e => console.log(e));
    }

    put(url: string, options: any, file = false, payload = 'json') {
        return this.fetchData(url, 'put', options, file, payload).then(d => d.json()).catch(e => console.log(e));
    }

    delete(url: string, options: any) {
        return this.fetchData(url, 'delete', options).then(d => d.json()).catch(e => console.log(e));
    }


    serializeParme(url: string, options: any) {
        let urlPath: string = url;
        if (options) {
            const paramsArray: any = [];
            //拼接参数  
            Object.keys(options).forEach(key => paramsArray.push(key + '=' + options[key]))
            if (url.search(/\?/) === -1) {
                urlPath += '?' + paramsArray.join('&')
            } else {
                urlPath += '&' + paramsArray.join('&')
            }
        }
        return urlPath;
    }
}

export default IrsFetchHttp;